@@ -183,56 +183,91 @@ check_endpoints <- function(worcs_directory = ".", verbose = TRUE, ...){
   return(invisible(all(replicates)))
 }
 
-#' @title Set up GitHub Actions to Check Endpoints
-#' @description Sets up a GitHub Action to perform continuous integration (CI)
-#' for a WORCS project. CI automatically evaluates `check_endpoints()` or
-#' `reproduce(check_endpoints = TRUE)`.
-#' at each push or pull request.
+
+#' @title List endpoints in WORCS project
+#' @description List the endpoints in a WORCS project.
 #' @param worcs_directory Character, indicating the WORCS project directory
 #' to which to save data. The default value "." points to the current directory.
 #' Default: '.'
-#' @return No return value. This function is called for its side effects.
+#' @param verbose Logical. Whether or not to print status messages to the
+#' console. Default: TRUE
+#' @param ... Additional arguments.
+#' @return None, prints to the console.
+#' @examples
+#' if(requireNamespace("withr", quietly = TRUE)){
+#'   withr::with_tempdir({
+#'     file.create(".worcs")
+#'     write.csv(iris, "iris.csv")
+#'     add_endpoint("iris.csv")
+#'     list_endpoints()
+#'   })
+#' }
 #' @seealso
-#'  \code{\link[usethis]{use_github_action}}
 #'  \code{\link[worcs]{add_endpoint}}
-#'  \code{\link[worcs]{check_endpoints}}
+#'  \code{\link[worcs]{snapshot_endpoints}}
 #' @export
-#' @importFrom usethis use_github_action
-github_action_check_endpoints <- function(worcs_directory = "."){
-  github_action_generic(worcs_directory = worcs_directory, url = "https://github.com/cjvanlissa/actions/blob/main/worcs_endpoints.yaml")
-}
-
-
-#' @rdname github_action_check_endpoints
-#' @export
-#' @importFrom usethis use_github_action
-github_action_reproduce <- function(worcs_directory = "."){
-  # Check if all data sources will be available on GitHub
-  has_data <- check_data_resources(dn_worcs = worcs_directory,
-                                   worcsfile = NULL,
-                                   verbose = TRUE)
-  gitig <- readLines(file.path(worcs_directory, ".gitignore"))
-  if(any(has_data$data_files %in% gitig)){
-    col_message(paste0("The following original data sources are not available on GitHub, which could prevent the GitHub action from reproducing your analysis:\n", paste0(has_data$data_files[which(has_data$data_files %in% gitig)], collapse = ", ")), success = FALSE)
-  }
-  github_action_generic(worcs_directory = worcs_directory, url = "https://github.com/cjvanlissa/actions/blob/main/worcs_reproduce.yaml")
-}
-
-github_action_generic <- function(worcs_directory = ".", url = NULL){
-  Args <- list(
-    url = url
-  )
-  if(!normalizePath(getwd()) == normalizePath(worcs_directory)){
-    usethis::ui_info("The current directory is not the same as 'worcs_directory'. The GitHub action might not install correctly.")
-  }
-
-  if("badge" %in% names(formals(usethis::use_github_action))){
-    Args$badge <- TRUE
-    if(file.exists(file.path(worcs_directory, "README.md"))){
-      Args$readme <- file.path(worcs_directory, "README.md")
-    }
+list_endpoints <- function(worcs_directory = ".", verbose = TRUE, ...){
+  dn_worcs <- dirname(check_recursive(file.path(normalizePath(worcs_directory),
+                                                ".worcs")))
+  fn_worcs <- file.path(dn_worcs, ".worcs")
+  worcsfile <- yaml::read_yaml(fn_worcs)
+  if(is.null(worcsfile[["endpoints"]])){
+    cli_msg("x" = "No endpoints found in WORCS project.")
   } else {
-    usethis::ui_oops("Could not add badge to readme.md; consider updating the 'usethis' package by running install.packages('usethis').")
+    endpoints <- worcsfile[["endpoints"]]
+    names(endpoints) <- rep("*", length(endpoints))
+    do.call(cli_msg, as.list(endpoints))
   }
-  do.call(usethis::use_github_action, Args)
+}
+
+#' @title Remove endpoint from WORCS project
+#' @description Remove an endpoint from a WORCS project.
+#' @param worcs_directory Character, indicating the WORCS project directory
+#' to which to save data. The default value "." points to the current directory.
+#' Default: '.'
+#' @param filename Character, indicating the file to be removed from the
+#' endpoints.
+#' Default: NULL.
+#' @param verbose Logical. Whether or not to print status messages to the
+#' console. Default: TRUE
+#' @param ... Additional arguments.
+#' @return None, prints to the console.
+#' @examples
+#' if(requireNamespace("withr", quietly = TRUE)){
+#'  withr::with_tempdir({
+#'    file.create(".worcs")
+#'    write.csv(iris, "iris.csv")
+#'    add_endpoint("iris.csv")
+#'    list_endpoints()
+#'    remove_endpoint("iris.csv")
+#'    list_endpoints()
+#'  })
+#' }
+#' @seealso
+#'  \code{\link[worcs]{add_endpoint}}
+#'  \code{\link[worcs]{snapshot_endpoints}}
+#' @export
+remove_endpoint <- function(filename = NULL, worcs_directory = ".", verbose = TRUE, ...){
+  if(is.null(filename)){
+    return(invisible(NULL))
+  }
+  dn_worcs <- dirname(check_recursive(file.path(normalizePath(worcs_directory),
+                                                ".worcs")))
+  fn_worcs <- file.path(dn_worcs, ".worcs")
+  worcsfile <- yaml::read_yaml(fn_worcs)
+  if(is.null(worcsfile[["endpoints"]])){
+    cli_msg("x" = "No endpoints found in WORCS project.")
+  } else {
+    endpoints <- worcsfile[["endpoints"]]
+    with_cli_try("Removing endpoint {.val {filename}} from WORCS project.", {
+      if(filename %in% endpoints){
+        endpoints <- endpoints[-which(endpoints == filename)]
+        # Append worcsfile
+        write_worcsfile(filename = fn_worcs, endpoints = endpoints, modify = TRUE)
+      } else {
+        stop()
+      }
+    })
+  }
+  invisible()
 }
